Crate lox_test_utils

Crate lox_test_utils 

Test utilities for the Lox ecosystem.

Provides approximate equality testing (approx_eq), test data helpers, and the #[derive(ApproxEq)] macro (behind the derive feature).

Modules

approx_eq
Approximate equality testing for floating-point types.

Macros

approx_eq
Checks if two values are approximately equal.
approx_ne
Checks if two values are not approximately equal.
assert_approx_eq
Asserts that two values are approximately equal.
assert_approx_ne
Asserts that two values are not approximately equal.

Functions

data_dir
Returns a PathBuf to the test fixture directory.
data_file
Returns a PathBuf to a file in the test fixture directory.
read_data_file
Returns the contents of the data file at path.