read_data_file

Function read_data_file 

pub fn read_data_file(path: impl AsRef<Path>) -> String
Returns the contents of the data file at path.

Panics

This function will panic if the file does not exist or is otherwise unreadable.